@@ -4,7 +4,8 @@
 StatDecomp <- ggproto("StatDecomp", Stat, 
                     required_aes = c("x", "y"),
                     
-                    compute_group = function(data, scales, frequency, type, ...) {
+                    compute_group = function(data, scales, frequency, type, 
+                                             index.ref, index.basis, ...) {
                        data <- data[order(data$x), ]
                        y_ts <- ts(data$y, frequency = frequency)
                        y_dc <- decompose(y_ts, type = type)
@@ -15,6 +16,12 @@ StatDecomp <- ggproto("StatDecomp", Stat,
                        }
                        
                        result <- data.frame(x = data$x, y = as.numeric(y_sa))
+                       
+                       if(!is.null(index.ref)){
+                          result$y <- index_help(result$y, ref = index.ref, 
+                                               basis = index.basis)
+                       }
+                       
                        return(result)
                     }
 )
@@ -30,6 +37,11 @@ StatDecomp <- ggproto("StatDecomp", Stat,
 #' @import ggplot2
 #' @param frequency The frequency for the time series
 #' @param type The type of seasonal component
+#' @param index.ref if not NULL, a vector of integers indicating which elements of
+#' the beginning of each series to use as a reference point for converting to an index.  
+#' If NULL, no conversion takes place and the data are presented on the original scale.
+#' @param index.basis if index.ref is not NULL, the basis point for converting
+#' to an index, most commonly 100 or 1000.  See examples.
 #' @param ... other arguments for the geom
 #' @inheritParams ggplot2::stat_identity
 #' @family time series stats for ggplot2
@@ -41,29 +53,37 @@ StatDecomp <- ggproto("StatDecomp", Stat,
 #' @examples
 #' ap_df <- tsdf(AirPassengers)
 #' 
-#' # default additive decomposition (doesn't work well in this case!):
+#' # Default additive decomposition (doesn't work well in this case!):
 #' ggplot(ap_df, aes(x = x, y = y)) +
 #'    stat_decomp(frequency = 12)
 #' 
-#' # multiplicative decomposition, more appropriate:
+#' # Multiplicative decomposition, more appropriate:
 #' ggplot(ap_df, aes(x = x, y = y)) +
 #'    stat_decomp(frequency = 12, type = "multiplicative")
 #' 
+#' # Multiple time series example:
 #' ggplot(ldeaths_df, aes(x = YearMon, y = deaths, colour = sex)) +
 #'   geom_point() +
 #'   facet_wrap(~sex) +
 #'   stat_decomp(frequency = 12) +
 #'   ggtitle("Seasonally adjusted lung deaths")
 #'
+#' # Example using index:
+#' ggplot(ldeaths_df, aes(x = YearMon, y = deaths, colour = sex)) +
+#'   facet_wrap(~sex) +
+#'   stat_rollapplyr(width = 12, align = "center", index.ref = 1:12, index.basis = 1000) +
+#'   ggtitle("Rolling annual median lung deaths, indexed (average month in 1974 = 1000)")
+#'
 stat_decomp <- function(mapping = NULL, data = NULL, geom = "line",
                       position = "identity", show.legend = NA, 
-                      inherit.aes = TRUE, frequency, type = c("additive", "multiplicative"), ...) {
+                      inherit.aes = TRUE, frequency, type = c("additive", "multiplicative"), 
+                      index.ref = NULL, index.basis = 100, ...) {
    type <- match.arg(type)
    ggplot2::layer(
       stat = StatDecomp, data = data, mapping = mapping, geom = geom, 
       position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-      params = list(frequency = frequency, type = type, 
-                    na.rm = FALSE, ...)
+      params = list(frequency = frequency, type = type, na.rm = FALSE, 
+                    index.ref = index.ref, index.basis = index.basis, ...)
       # note that this function is unforgiving of NAs.
    )
 }
